#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_django-registration-with-email
------------

Tests for `django-registration-with-email` models module.
"""

from django.test import TestCase

from django_registration_with_email import models


class TestDjango_registration_with_email(TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
